@@ -15,9 +15,9 @@
     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
     GNU General Public License for more details.
 
-    You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+    You should have received a copy of the GNU General Public License along
+    with this program; if not, write to the Free Software Foundation, Inc.,
+    51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 
  */
 
@@ -133,7 +133,9 @@ colour_set_colour( Colour *colour,
 	for( i = 0; i < 3; i++ )
 		if( !DEQ( value[i], colour->value[i] ) )
 			break;
-	if( i == 3 && strcmp( colour_space, colour->colour_space ) == 0 )
+	if( i == 3 && 
+		colour_space &&
+		strcmp( colour_space, colour->colour_space ) == 0 )
 		return;
 
 	for( i = 0; i < 3; i++ )
@@ -176,8 +178,11 @@ colour_ii_new( Colour *colour )
 static void
 colour_get_rgb( Colour *colour, double rgb[4] )
 {
+	int i;
 	Imageinfo *imageinfo;
 
+	for( i = 0; i < 4; i++ ) 
+		rgb[i] = 0.0;
 	if( (imageinfo = colour_ii_new( colour )) )
 		imageinfo_to_rgb( imageinfo, rgb );
 }
@@ -253,21 +258,20 @@ colour_edit( GtkWidget *parent, Model *model )
 	Colour *colour = COLOUR( model );
 	ColourEdit *eds = INEW( NULL, ColourEdit );
 	GtkWidget *idlg;
-	char txt[100];
-	VipsBuf buf = VIPS_BUF_STATIC( txt );
 
 	eds->colour = colour;
 
 	idlg = idialog_new();
-	row_qualified_name( HEAPMODEL( colour )->row, &buf );
-	iwindow_set_title( IWINDOW( idlg ), 
-		_( "Edit Color \"%s\"" ), vips_buf_all( &buf ) );
+	iwindow_set_title( IWINDOW( idlg ), _( "Edit %s %s" ),
+		IOBJECT_GET_CLASS_NAME( model ),
+		IOBJECT( HEAPMODEL( model )->row )->name );
 	idialog_set_build( IDIALOG( idlg ), 
 		(iWindowBuildFn) colour_buildedit, eds, NULL, NULL );
 	idialog_set_callbacks( IDIALOG( idlg ), 
 		iwindow_true_cb, NULL, idialog_free_client, eds );
 	idialog_add_ok( IDIALOG( idlg ), 
-		colour_done_cb, _( "Set Color" ) );
+		colour_done_cb, _( "Set %s" ), 
+		IOBJECT_GET_CLASS_NAME( model ) );
 	iwindow_set_parent( IWINDOW( idlg ), parent );
 	idialog_set_iobject( IDIALOG( idlg ), IOBJECT( model ) );
 	idialog_set_pinup( IDIALOG( idlg ), TRUE );
