@@ -15,9 +15,9 @@
     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
     GNU General Public License for more details.
 
-    You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+    You should have received a copy of the GNU General Public License along
+    with this program; if not, write to the Free Software Foundation, Inc.,
+    51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 
  */
 
@@ -73,14 +73,14 @@ typedef struct _FilemodelClass {
 
 		set_modified	set/clear the modified state
 
-		save_all	top level save ... intercept this to override
+		top_save	top level save ... intercept this to override
 
 	 */
 
 	gboolean (*top_load)( Filemodel *filemodel, 
 		ModelLoadState *state, Model *parent, xmlNode *xnode );
 	void (*set_modified)( Filemodel *filemodel, gboolean modified );
-	gboolean (*save_all)( Filemodel *filemodel, const char *filename );
+	gboolean (*top_save)( Filemodel *filemodel, const char *filename );
 
 	FileselFileType **filetype;
 	const char *filetype_pref;
@@ -100,9 +100,9 @@ iWindow *filemodel_get_window_hint( Filemodel *filemodel );
 GType filemodel_get_type( void );
 
 void filemodel_set_offset( Filemodel *filemodel, int x_off, int y_off );
-gboolean filemodel_save_all( Filemodel *filemodel, const char *filename );
-gboolean filemodel_load_all( Filemodel *filemodel, 
-	Model *parent, const char *filename );
+gboolean filemodel_top_save( Filemodel *filemodel, const char *filename );
+gboolean filemodel_load_all( Filemodel *filemodel, Model *parent, 
+	const char *filename, const char *filename_user );
 gboolean filemodel_load_all_openfile( Filemodel *filemodel, 
 	Model *parent, iOpenFile *of );
 
