@@ -1,4 +1,4 @@
-/* Declarations for mainw.
+/* A top level window holding some workspaces
  */
 
 /*
@@ -15,9 +15,9 @@
     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
     GNU General Public License for more details.
 
-    You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+    You should have received a copy of the GNU General Public License along
+    with this program; if not, write to the Free Software Foundation, Inc.,
+    51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 
  */
 
@@ -43,13 +43,14 @@
 struct _Mainw {
 	iWindow parent_object;
 
-	/* Workspace we display.
+	/* Our model.
 	 */
-	Workspace *ws;
+	Workspacegroup *wsg;
 	guint changed_sid;
 	guint destroy_sid;
 
-	/* Also watch for changed on heap and image, and prefs.
+	/* Watch for changed on heap and image, and prefs. Use to update
+	 * status bar and space free.
 	 */
 	guint imageinfo_changed_sid;
 	guint heap_changed_sid;
@@ -62,6 +63,10 @@ struct _Mainw {
 	guint end_sid;	
 	gboolean cancel;
 
+	/* Batch refresh with this, it's slow.
+	 */
+	guint refresh_timeout;
+
 	/* Display MB free in tmp, or cells free in heap.
 	 */
 	gboolean free_type;
@@ -72,28 +77,20 @@ struct _Mainw {
 	gboolean toolbar_visible;
 	gboolean statusbar_visible;
 
-	/* The last row we visited with the 'next-error' button.
+	/* The kitg the toolkit menu is currently displaying. Use this to
+	 * avoid rebuilding the toolkit menu on every tab switch.
 	 */
-	Row *row_last_error;
-
-	/* Wait before popping up the compat dialog. How stupid, but we have
-	 * to make sure our window is on the server before we can show an info
-	 * box off it.
-	 */
-	guint compat_timeout;
+	Toolkitgroup *kitg;
 
 	/* Component widgets.
 	 */
 	Toolkitgroupview *kitgview;
-	Toolkitbrowser *toolkitbrowser;
-	Workspacedefs *workspacedefs;
-	Workspaceview *wsview;
 	GtkWidget *toolbar;
 	GtkWidget *recent_menu;
 	GtkWidget *jump_to_column_menu;
+	GtkWidget *toolkit_menu;
 
-	GtkWidget *popup;
-	GtkWidget *popup_jump;
+	Workspacegroupview *wsgview;
 
 	GtkWidget *statusbar_main;
 	GtkWidget *statusbar;
@@ -101,11 +98,6 @@ struct _Mainw {
 	GtkWidget *space_free_eb;	
 	GtkWidget *progress_box;
 	GtkWidget *progress;
-
-	/* Left and right panes ... program window and toolkit browser.
-	 */
-	Pane *lpane;
-	Pane *rpane;
 };
 
 typedef struct _MainwClass {
@@ -129,16 +121,31 @@ void mainw_recent_freeze( void );
 void mainw_recent_thaw( void );
 void mainw_recent_add( GSList **recent, const char *filename );
 
-int mainw_number( void );
 Mainw *mainw_pick_one( void );
 GType mainw_get_type( void );
 
 void mainw_find_disc( VipsBuf *buf );
 void mainw_find_heap( VipsBuf *buf, Heap *heap );
 
+Workspace *mainw_get_workspace( Mainw *mainw );
+
 void mainw_homepage_action_cb( GtkAction *action, iWindow *iwnd );
 void mainw_about_action_cb( GtkAction *action, iWindow *iwnd );
 void mainw_guide_action_cb( GtkAction *action, iWindow *iwnd );
-Workspace *mainw_open_file_into_workspace( Mainw *mainw, const char *filename );
-Mainw *mainw_new( Workspace *ws );
 
+void mainw_column_new_action_cb( GtkAction *action, Mainw *mainw );
+void mainw_workspace_merge( Mainw *mainw );
+void mainw_workspace_merge_action_cb( GtkAction *action, Mainw *mainw );
+void mainw_layout_action_cb( GtkAction *action, Mainw *mainw );
+void mainw_group_action_cb( GtkAction *action, Mainw *mainw );
+void mainw_next_error_action_cb( GtkAction *action, Mainw *mainw );
+void mainw_open_action_cb( GtkAction *action, Mainw *mainw );
+
+Workspacegroup *mainw_open_workspace( Workspaceroot *wsr, 
+	const char *filename );
+
+Mainw *mainw_new( Workspacegroup *wsg );
+
+void mainw_cull( void );
+
+void mainw_layout( void );
