@@ -15,9 +15,9 @@
     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
     GNU General Public License for more details.
 
-    You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+    You should have received a copy of the GNU General Public License along
+    with this program; if not, write to the Free Software Foundation, Inc.,
+    51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 
  */
 
@@ -64,7 +64,6 @@ rowview_destroy( GtkObject *object )
 	printf( "\n" );
 #endif /*DEBUG*/
 
-	IM_FREEF( g_source_remove, rview->set_name_tid );
 	IM_FREE( rview->last_tooltip );
 
 	/* Kill children ... must do this ourselves, since we are not a
@@ -94,53 +93,6 @@ rowview_attach( Rowview *rview, GtkWidget *child, int x,
 	gtk_widget_unref( child );
 }
 
-static gboolean
-rowview_set_name_cb( Rowview *rview )
-{
-	rview->set_name_tid = 0;
-
-#ifdef DEBUG
-	printf( "rowview_set_name_cb: " );
-	row_name_print( ROW( VOBJECT( rview )->iobject ) );
-	printf( ".name = %s\n", rview->to_set_name );
-#endif /*DEBUG*/
-
-	gtk_widget_set_name( rview->but, rview->to_set_name );
-	rview->set_name = rview->to_set_name;
-	rview->to_set_name = NULL;
-
-	return( FALSE );
-}
-
-static void
-rowview_set_name( Rowview *rview, const char *set_name )
-{
-	gboolean changed = FALSE;
-
-	/* If there's a timeout currently set, test against the name we're
-	 * planning to set. Pointer equality is mostly good enough .. we are 
-	 * setting with static strings.
-	 */
-	if( rview->set_name_tid && set_name != rview->to_set_name ) {
-		rview->to_set_name = set_name;
-		changed = TRUE;
-	}
-	/* No timeout? Test against the current name.
-	 */
-	else if( set_name != rview->set_name ) {
-		rview->to_set_name = set_name;
-		changed = TRUE;
-	}
-
-	if( changed ) {
-		/* Reset the timeout.
-		 */
-		IM_FREEF( g_source_remove, rview->set_name_tid );
-		rview->set_name_tid = g_timeout_add( 200, 
-			(GSourceFunc) rowview_set_name_cb, rview );
-	}
-}
-
 static void
 rowview_update_widgets( Rowview *rview )
 {
@@ -152,6 +104,7 @@ rowview_update_widgets( Rowview *rview )
 	printf( "rowview_refresh: " );
 	row_name_print( row );
 	printf( "\n" );
+	printf( "\teditable == %d\n", editable ); 
 #endif /*DEBUG*/
 
 	/* Attach widgets to parent in new place.
@@ -176,16 +129,6 @@ rowview_update_widgets( Rowview *rview )
 				GTK_EXPAND | GTK_FILL, GTK_EXPAND | GTK_FILL );
 	}
 
-	/* Update button.
-	 */
-        set_glabel( rview->label, "%s", row_name( row ) );
-	widget_visible( rview->but, rview->visible && editable );
-
-	/* Spin visible only if this is a class. 
-	 */
-	widget_visible( rview->spin, 
-		rview->visible && row->is_class && editable );
-
         /* Set colours.
          */
 	if( CALC_DISPLAY_LED ) {
@@ -220,10 +163,23 @@ rowview_update_widgets( Rowview *rview )
 		else if( row->dirty )
 			name = "dirty_widget";
 
-		rowview_set_name( rview, name );
+		gtk_widget_set_name( rview->but, name );
 	}
 	widget_visible( rview->led, 
 		rview->visible && CALC_DISPLAY_LED && editable );
+
+	/* Update button.
+	 */
+        set_glabel( rview->label, "%s", row_name( row ) );
+	widget_visible( rview->but, rview->visible && editable );
+
+	/* Spin visible only if this is a class. 
+	 */
+	widget_visible( rview->spin, 
+		rview->visible && row->is_class && editable );
+
+	if( rview->rhsview )
+		widget_visible( GTK_WIDGET( rview->rhsview ), rview->visible );
 }
 
 static void 
@@ -249,11 +205,11 @@ rowview_refresh( vObject *vobject )
 /* Single click on button callback.
  */
 static void
-rowview_single_cb( GtkWidget *wid, Rowview *rview, guint state )
+rowview_single_cb( GtkWidget *wid, GdkEvent *event, Rowview *rview )
 {
 	Row *row = ROW( VOBJECT( rview )->iobject );
 
-	row_select_modifier( row, state );
+	row_select_modifier( row, event->button.state );
 }
 
 /* Edit our object.
@@ -273,7 +229,7 @@ rowview_edit( Rowview *rview )
 /* Double click on button callback.
  */
 static void
-rowview_double_cb( GtkWidget *button, Rowview *rview )
+rowview_double_cb( GtkWidget *button, GdkEvent *event, Rowview *rview )
 {
 	if( !rowview_edit( rview ) ) 
 		iwindow_alert( button, GTK_MESSAGE_ERROR );
@@ -331,7 +287,7 @@ rowview_clone_cb( GtkWidget *menu, GtkWidget *button, Rowview *rview )
 
         workspace_deselect_all( ws );
         row_select( row );
-        if( !workspace_clone_selected( ws ) )
+        if( !workspace_selected_duplicate( ws ) )
 		iwindow_alert( button, GTK_MESSAGE_ERROR );
         workspace_deselect_all( ws );
 
@@ -399,7 +355,8 @@ rowview_recalc_cb( GtkWidget *menu, GtkWidget *button, Rowview *rview )
 
 	/* Now ... pick up any errors.
 	 */
-	if( symbol_recalculate_check( row->sym ) )
+	if( row->sym &&
+		!symbol_recalculate_check( row->sym ) )
 		iwindow_alert( button, GTK_MESSAGE_ERROR );
 }
 
@@ -438,7 +395,7 @@ rowview_spin_up_cb( GtkWidget *widget, gpointer client )
 	Rhs *rhs = row->child_rhs;
 
 	rhs_vislevel_down( rhs );
-	filemodel_set_modified( FILEMODEL( row->ws ), TRUE );
+	workspace_set_modified( row->ws, TRUE );
 }
 
 static void
@@ -449,7 +406,7 @@ rowview_spin_down_cb( GtkWidget *widget, gpointer client )
 	Rhs *rhs = row->child_rhs;
 
 	rhs_vislevel_up( rhs );
-	filemodel_set_modified( FILEMODEL( row->ws ), TRUE );
+	workspace_set_modified( row->ws, TRUE );
 }
 
 /* Scroll to make tally entry visible. 
@@ -550,13 +507,13 @@ rowview_link( View *view, Model *model, View *parent )
 	 */
 	if( row->top_row == row ) {
 		gtk_drag_source_set( rview->but, GDK_BUTTON1_MASK, 
-			rowview_target_table, IM_NUMBER( rowview_target_table ), 
+			rowview_target_table, IM_NUMBER( rowview_target_table ),
 			GDK_ACTION_COPY );
 		gtk_signal_connect( GTK_OBJECT( rview->but ), "drag_data_get",
 			GTK_SIGNAL_FUNC( rowview_drag_data_get ), rview );
 
 		gtk_drag_dest_set( rview->but, GTK_DEST_DEFAULT_ALL,
-			rowview_target_table, IM_NUMBER( rowview_target_table ), 
+			rowview_target_table, IM_NUMBER( rowview_target_table ),
 			GDK_ACTION_COPY );
 		gtk_signal_connect( GTK_OBJECT( rview->but ), 
 			"drag_data_received",
@@ -579,27 +536,42 @@ rowview_child_add( View *parent, View *child )
 	VIEW_CLASS( parent_class )->child_add( parent, child );
 }
 
+static void
+rowview_child_remove( View *parent, View *child )
+{
+	Rowview *rowview = ROWVIEW( parent );
+
+	g_assert( IS_RHSVIEW( child ) );
+	g_assert( rowview->rhsview );
+
+	rowview->rhsview = NULL;
+
+	VIEW_CLASS( parent_class )->child_remove( parent, child );
+}
+
 static void
 rowview_class_init( RowviewClass *class )
 {
-	GtkWidget *pane;
 	GtkObjectClass *object_class = (GtkObjectClass *) class;
 	vObjectClass *vobject_class = (vObjectClass *) class;
 	ViewClass *view_class = (ViewClass *) class;
 
-	parent_class = g_type_class_peek_parent( class );
+	GtkWidget *pane;
 
-	object_class->destroy = rowview_destroy;
+	parent_class = g_type_class_peek_parent( class );
 
 	/* Create signals.
 	 */
 
 	/* Init methods.
 	 */
+	object_class->destroy = rowview_destroy;
+
 	vobject_class->refresh = rowview_refresh;
 
 	view_class->link = rowview_link;
 	view_class->child_add = rowview_child_add;
+	view_class->child_remove = rowview_child_remove;
 	view_class->reset = rowview_reset;
 	view_class->scrollto = rowview_scrollto;
 
@@ -666,9 +638,6 @@ rowview_init( Rowview *rview )
 {
         rview->visible = TRUE; 
 	rview->rnum = -1;
-        rview->set_name_tid = 0; 
-        rview->set_name = NULL; 
-        rview->to_set_name = NULL; 
         rview->last_tooltip = NULL; 
 
 	/* Make leds.
@@ -786,21 +755,14 @@ rowview_get_position( Rowview *rview, int *x, int *y, int *w, int *h )
 #endif /*DEBUG*/
 }
 
-/* Hide/show a row. We can't use MODEL( row )->display for this, since tables
- * don't like it :-( just _show()/_hide() rather then _create()/_destroy()
+/* Hide/show a row. 
  */
 void 
 rowview_set_visible( Rowview *rview, gboolean visible )
 {
-	Row *row = ROW( VOBJECT( rview )->iobject );
-
 	if( rview->visible != visible ) {
-		widget_visible( rview->but, visible );
-		widget_visible( rview->spin, visible && row->is_class );
-		widget_visible( rview->led, visible && CALC_DISPLAY_LED );
-		if( rview->rhsview )
-			widget_visible( GTK_WIDGET( rview->rhsview ), visible );
 		rview->visible = visible;
+		rowview_update_widgets( rview );
 	}
 }
 
