@@ -15,9 +15,9 @@
     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
     GNU General Public License for more details.
 
-    You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+    You should have received a copy of the GNU General Public License along
+    with this program; if not, write to the Free Software Foundation, Inc.,
+    51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 
  */
 
@@ -45,9 +45,6 @@ struct _Rowview {
 
 	gboolean visible;	/* Currently visible */
         int rnum;		/* Row of tallycolumn we are in */
-        guint set_name_tid;	/* id of set_name delay timer */
-	const char *set_name;	/* Name we last set */
-	const char *to_set_name;/* Name we are waiting to set */
 
         GtkWidget *spin;   	/* Class display open/close widgets */
         GtkWidget *but;   	/* Name button */
