@@ -15,9 +15,9 @@
     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
     GNU General Public License for more details.
 
-    You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+    You should have received a copy of the GNU General Public License along
+    with this program; if not, write to the Free Software Foundation, Inc.,
+    51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 
  */
 
@@ -38,17 +38,18 @@
 #define IS_TOOLKITBROWSER_CLASS( klass ) \
 	(GTK_CHECK_CLASS_TYPE( (klass), TYPE_TOOLKITBROWSER ))
 
-typedef struct _Toolkitbrowser {
+struct _Toolkitbrowser {
 	vObject parent_object;
 
-	Mainw *mainw;			/* Mainw whose kits we explore */
+	Toolkitgroup *kitg;
+	Workspace *ws;
 
 	GtkListStore *store;		/* Model for list view */
 	GtkTreeModel *filter;		/* After filtering with search box */
 	GtkWidget *tree;		/* Displayed tree */
 	GtkWidget *entry;		/* Search widget */
 	GtkWidget *top;			/* hbox for top bar */
-} Toolkitbrowser;
+};
 
 typedef struct _ToolkitbrowserClass {
 	vObjectClass parent_class;
@@ -59,4 +60,6 @@ GtkType toolkitbrowser_get_type( void );
 void toolkitbrowser_set_mainw( Toolkitbrowser *toolkitbrowser, Mainw *mainw );
 Toolkitbrowser *toolkitbrowser_new( void );
 int toolkitbrowser_get_width( Toolkitbrowser *toolkitbrowser );
+void toolkitbrowser_set_workspace( Toolkitbrowser *toolkitbrowser, 
+	Workspace *ws );
 
