@@ -15,9 +15,9 @@
     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
     GNU General Public License for more details.
 
-    You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+    You should have received a copy of the GNU General Public License along
+    with this program; if not, write to the Free Software Foundation, Inc.,
+    51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 
  */
 
@@ -121,6 +121,8 @@ valueview_init( Valueview *valueview )
 #endif /*DEBUG*/
 
         valueview->eb = gtk_event_box_new();
+	gtk_widget_add_events( GTK_WIDGET( valueview->eb ), 
+		GDK_POINTER_MOTION_HINT_MASK ); 
         gtk_box_pack_start( GTK_BOX( valueview ), 
 		valueview->eb, FALSE, FALSE, 0 );
 	valueview->label = gtk_label_new( "" );
